==> elasticache-1.93.0-sources.jar: software/amazon/awscdk/services/elasticache/CfnSecurityGroupIngressProps.java <==
package software.amazon.awscdk.services.elasticache;

/**
 * Properties for defining a `AWS::ElastiCache::SecurityGroupIngress`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:21.536Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.elasticache.$Module.class, fqn = "@aws-cdk/aws-elasticache.CfnSecurityGroupIngressProps")
@software.amazon.jsii.Jsii.Proxy(CfnSecurityGroupIngressProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnSecurityGroupIngressProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::ElastiCache::SecurityGroupIngress.CacheSecurityGroupName`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getCacheSecurityGroupName();

    /**
     * `AWS::ElastiCache::SecurityGroupIngress.EC2SecurityGroupName`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getEc2SecurityGroupName();

    /**
     * `AWS::ElastiCache::SecurityGroupIngress.EC2SecurityGroupOwnerId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getEc2SecurityGroupOwnerId() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnSecurityGroupIngressProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnSecurityGroupIngressProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnSecurityGroupIngressProps> {
        private java.lang.String cacheSecurityGroupName;
        private java.lang.String ec2SecurityGroupName;
        private java.lang.String ec2SecurityGroupOwnerId;

        /**
         * Sets the value of {@link CfnSecurityGroupIngressProps#getCacheSecurityGroupName}
         * @param cacheSecurityGroupName `AWS::ElastiCache::SecurityGroupIngress.CacheSecurityGroupName`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cacheSecurityGroupName(java.lang.String cacheSecurityGroupName) {
            this.cacheSecurityGroupName = cacheSecurityGroupName;
            return this;
        }

        /**
         * Sets the value of {@link CfnSecurityGroupIngressProps#getEc2SecurityGroupName}
         * @param ec2SecurityGroupName `AWS::ElastiCache::SecurityGroupIngress.EC2SecurityGroupName`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ec2SecurityGroupName(java.lang.String ec2SecurityGroupName) {
            this.ec2SecurityGroupName = ec2SecurityGroupName;
            return this;
        }

        /**
         * Sets the value of {@link CfnSecurityGroupIngressProps#getEc2SecurityGroupOwnerId}
         * @param ec2SecurityGroupOwnerId `AWS::ElastiCache::SecurityGroupIngress.EC2SecurityGroupOwnerId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ec2SecurityGroupOwnerId(java.lang.String ec2SecurityGroupOwnerId) {
            this.ec2SecurityGroupOwnerId = ec2SecurityGroupOwnerId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnSecurityGroupIngressProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnSecurityGroupIngressProps build() {
            return new Jsii$Proxy(cacheSecurityGroupName, ec2SecurityGroupName, ec2SecurityGroupOwnerId);
        }
    }

    /**
     * An implementation for {@link CfnSecurityGroupIngressProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnSecurityGroupIngressProps {
        private final java.lang.String cacheSecurityGroupName;
        private final java.lang.String ec2SecurityGroupName;
        private final java.lang.String ec2SecurityGroupOwnerId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.cacheSecurityGroupName = software.amazon.jsii.Kernel.get(this, "cacheSecurityGroupName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.ec2SecurityGroupName = software.amazon.jsii.Kernel.get(this, "ec2SecurityGroupName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.ec2SecurityGroupOwnerId = software.amazon.jsii.Kernel.get(this, "ec2SecurityGroupOwnerId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String cacheSecurityGroupName, final java.lang.String ec2SecurityGroupName, final java.lang.String ec2SecurityGroupOwnerId) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.cacheSecurityGroupName = java.util.Objects.requireNonNull(cacheSecurityGroupName, "cacheSecurityGroupName is required");
            this.ec2SecurityGroupName = java.util.Objects.requireNonNull(ec2SecurityGroupName, "ec2SecurityGroupName is required");
            this.ec2SecurityGroupOwnerId = ec2SecurityGroupOwnerId;
        }

        @Override
        public final java.lang.String getCacheSecurityGroupName() {
            return this.cacheSecurityGroupName;
        }

        @Override
        public final java.lang.String getEc2SecurityGroupName() {
            return this.ec2SecurityGroupName;
        }

        @Override
        public final java.lang.String getEc2SecurityGroupOwnerId() {
            return this.ec2SecurityGroupOwnerId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("cacheSecurityGroupName", om.valueToTree(this.getCacheSecurityGroupName()));
            data.set("ec2SecurityGroupName", om.valueToTree(this.getEc2SecurityGroupName()));
            if (this.getEc2SecurityGroupOwnerId() != null) {
                data.set("ec2SecurityGroupOwnerId", om.valueToTree(this.getEc2SecurityGroupOwnerId()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-elasticache.CfnSecurityGroupIngressProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnSecurityGroupIngressProps.Jsii$Proxy that = (CfnSecurityGroupIngressProps.Jsii$Proxy) o;

            if (!cacheSecurityGroupName.equals(that.cacheSecurityGroupName)) return false;
            if (!ec2SecurityGroupName.equals(that.ec2SecurityGroupName)) return false;
            return this.ec2SecurityGroupOwnerId != null ? this.ec2SecurityGroupOwnerId.equals(that.ec2SecurityGroupOwnerId) : that.ec2SecurityGroupOwnerId == null;
        }

        @Override
        public final int hashCode() {
            int result = this.cacheSecurityGroupName.hashCode();
            result = 31 * result + (this.ec2SecurityGroupName.hashCode());
            result = 31 * result + (this.ec2SecurityGroupOwnerId != null ? this.ec2SecurityGroupOwnerId.hashCode() : 0);
            return result;
        }
    }
}

==> elasticache-1.204.0-sources.jar: software/amazon/awscdk/services/elasticache/CfnSecurityGroupIngressProps.java <==
package software.amazon.awscdk.services.elasticache;

/**
 * Properties for defining a <code>CfnSecurityGroupIngress</code>.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.elasticache.*;
 * CfnSecurityGroupIngressProps cfnSecurityGroupIngressProps = CfnSecurityGroupIngressProps.builder()
 *         .cacheSecurityGroupName("cacheSecurityGroupName")
 *         .ec2SecurityGroupName("ec2SecurityGroupName")
 *         // the properties below are optional
 *         .ec2SecurityGroupOwnerId("ec2SecurityGroupOwnerId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.84.0 (build 5404dcf)", date = "2023-06-19T16:29:56.504Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.elasticache.$Module.class, fqn = "@aws-cdk/aws-elasticache.CfnSecurityGroupIngressProps")
@software.amazon.jsii.Jsii.Proxy(CfnSecurityGroupIngressProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnSecurityGroupIngressProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The name of the Cache Security Group to authorize.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getCacheSecurityGroupName();

    /**
     * Name of the EC2 Security Group to include in the authorization.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getEc2SecurityGroupName();

    /**
     * Specifies the Amazon Account ID of the owner of the EC2 security group specified in the EC2SecurityGroupName property.
     * <p>
     * The Amazon access key ID is not an acceptable value.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getEc2SecurityGroupOwnerId() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnSecurityGroupIngressProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnSecurityGroupIngressProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnSecurityGroupIngressProps> {
        java.lang.String cacheSecurityGroupName;
        java.lang.String ec2SecurityGroupName;
        java.lang.String ec2SecurityGroupOwnerId;

        /**
         * Sets the value of {@link CfnSecurityGroupIngressProps#getCacheSecurityGroupName}
         * @param cacheSecurityGroupName The name of the Cache Security Group to authorize. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cacheSecurityGroupName(java.lang.String cacheSecurityGroupName) {
            this.cacheSecurityGroupName = cacheSecurityGroupName;
            return this;
        }

        /**
         * Sets the value of {@link CfnSecurityGroupIngressProps#getEc2SecurityGroupName}
         * @param ec2SecurityGroupName Name of the EC2 Security Group to include in the authorization. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ec2SecurityGroupName(java.lang.String ec2SecurityGroupName) {
            this.ec2SecurityGroupName = ec2SecurityGroupName;
            return this;
        }

        /**
         * Sets the value of {@link CfnSecurityGroupIngressProps#getEc2SecurityGroupOwnerId}
         * @param ec2SecurityGroupOwnerId Specifies the Amazon Account ID of the owner of the EC2 security group specified in the EC2SecurityGroupName property.
         *                                The Amazon access key ID is not an acceptable value.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ec2SecurityGroupOwnerId(java.lang.String ec2SecurityGroupOwnerId) {
            this.ec2SecurityGroupOwnerId = ec2SecurityGroupOwnerId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnSecurityGroupIngressProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnSecurityGroupIngressProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnSecurityGroupIngressProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnSecurityGroupIngressProps {
        private final java.lang.String cacheSecurityGroupName;
        private final java.lang.String ec2SecurityGroupName;
        private final java.lang.String ec2SecurityGroupOwnerId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.cacheSecurityGroupName = software.amazon.jsii.Kernel.get(this, "cacheSecurityGroupName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.ec2SecurityGroupName = software.amazon.jsii.Kernel.get(this, "ec2SecurityGroupName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.ec2SecurityGroupOwnerId = software.amazon.jsii.Kernel.get(this, "ec2SecurityGroupOwnerId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.cacheSecurityGroupName = java.util.Objects.requireNonNull(builder.cacheSecurityGroupName, "cacheSecurityGroupName is required");
            this.ec2SecurityGroupName = java.util.Objects.requireNonNull(builder.ec2SecurityGroupName, "ec2SecurityGroupName is required");
            this.ec2SecurityGroupOwnerId = builder.ec2SecurityGroupOwnerId;
        }

        @Override
        public final java.lang.String getCacheSecurityGroupName() {
            return this.cacheSecurityGroupName;
        }

        @Override
        public final java.lang.String getEc2SecurityGroupName() {
            return this.ec2SecurityGroupName;
        }

        @Override
        public final java.lang.String getEc2SecurityGroupOwnerId() {
            return this.ec2SecurityGroupOwnerId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("cacheSecurityGroupName", om.valueToTree(this.getCacheSecurityGroupName()));
            data.set("ec2SecurityGroupName", om.valueToTree(this.getEc2SecurityGroupName()));
            if (this.getEc2SecurityGroupOwnerId() != null) {
                data.set("ec2SecurityGroupOwnerId", om.valueToTree(this.getEc2SecurityGroupOwnerId()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-elasticache.CfnSecurityGroupIngressProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnSecurityGroupIngressProps.Jsii$Proxy that = (CfnSecurityGroupIngressProps.Jsii$Proxy) o;

            if (!cacheSecurityGroupName.equals(that.cacheSecurityGroupName)) return false;
            if (!ec2SecurityGroupName.equals(that.ec2SecurityGroupName)) return false;
            return this.ec2SecurityGroupOwnerId != null ? this.ec2SecurityGroupOwnerId.equals(that.ec2SecurityGroupOwnerId) : that.ec2SecurityGroupOwnerId == null;
        }

        @Override
        public final int hashCode() {
            int result = this.cacheSecurityGroupName.hashCode();
            result = 31 * result + (this.ec2SecurityGroupName.hashCode());
            result = 31 * result + (this.ec2SecurityGroupOwnerId != null ? this.ec2SecurityGroupOwnerId.hashCode() : 0);
            return result;
        }
    }
}
